@@ -52,6 +52,7 @@ price_indices <-
   "cswd",
   "harmonic",
   "bmw",
+  "dikhanov",
   "laspeyres",
   "paasche",
   "fisher",
@@ -89,6 +90,7 @@ price_indices <-
   "chcarli",
   "chcswd",
   "chharmonic",
+  "chdikhanov",
   "chlaspeyres",
   "chpaasche",
   "chfisher",
